@@ -110,14 +110,19 @@ def _load_packages(
     resolve_aliases: bool = True,
     only_exported: bool = True,
     only_known_modules: bool = True,
+    allow_inspection: bool = True,
 ):
     loader = GriffeLoader(
         extensions=extensions,
         search_paths=search_paths,
         docstring_parser=docstring_parser,
         docstring_options=docstring_options,
+        allow_inspection=allow_inspection,
     )
     for package in packages:
+        if not package:
+            logger.debug("Empty package name, continuing")
+            continue
         logger.info(f"Loading package {package}")
         try:
             loader.load_module(package)
@@ -125,8 +130,9 @@ def _load_packages(
             logger.error(f"Could not find package {package}: {error}")
         except ImportError as error:
             logger.error(f"Tried but could not import package {package}: {error}")
-    logger.info("Finished loading packages, starting alias resolution")
+    logger.info("Finished loading packages")
     if resolve_aliases:
+        logger.info("Starting alias resolution")
         unresolved, iterations = loader.resolve_aliases(only_exported, only_known_modules)
         if unresolved:
             logger.info(f"{len(unresolved)} aliases were still unresolved after {iterations} iterations")
@@ -240,6 +246,12 @@ def get_parser() -> argparse.ArgumentParser:
         action="store_true",
         help="Show statistics at the end.",
     )
+    parser.add_argument(
+        "-X",
+        "--no-inspection",
+        action="store_true",
+        help="Disallow inspection of builtin/compiled/not found modules.",
+    )
 
     parser.add_argument("packages", metavar="PACKAGE", nargs="+", help="Packages to find and parse.")
     return parser
@@ -296,13 +308,14 @@ def main(args: list[str] | None = None) -> int:  # noqa: WPS231
         opts.resolve_aliases,
         not opts.resolve_implicit,
         not opts.resolve_external,
+        not opts.no_inspection,
     )
     packages = loader.modules_collection.members
 
     started = datetime.now()
     if per_package_output:
         for package_name, data in packages.items():
-            serialized = json.dumps(data, cls=JSONEncoder, indent=2, full=opts.full)
+            serialized = data.as_json(indent=2, full=opts.full)
             _print_data(serialized, output.format(package=package_name))
     else:
         serialized = json.dumps(packages, cls=JSONEncoder, indent=2, full=opts.full)
