@@ -1,5 +1,7 @@
 """Tests for the `cli` module."""
 
+import sys
+
 import pytest
 
 from griffe import cli
@@ -7,7 +9,10 @@ from griffe import cli
 
 def test_main():
     """Basic CLI test."""
-    assert cli.main(["griffe", "-s", "src", "-o/dev/null"]) == 0
+    if sys.platform == "win32":
+        assert cli.main(["griffe", "-s", "src", "-oNUL"]) == 0
+    else:
+        assert cli.main(["griffe", "-s", "src", "-o/dev/null"]) == 0
 
 
 def test_show_help(capsys):
