@@ -204,3 +204,34 @@ def test_overwrite_module_with_attribute():
         loader = GriffeLoader(search_paths=[tmp_package.tmpdir])
         loader.load_module(tmp_package.name)
         loader.resolve_aliases()
+
+
+def test_load_package_from_both_py_and_pyi_files():
+    """Check that the loader is able to merge a package loaded from `*.py` and `*.pyi` files.
+
+    This is a special case of the previous test: where the package itself has a top level
+    `__init__.pyi` (not so uncommon).
+    """
+    with temporary_pypackage("package", ["__init__.py", "__init__.pyi"]) as tmp_package:
+        tmp_package.path.joinpath("__init__.py").write_text("globals()['f'] = lambda x: str(x)")
+        tmp_package.path.joinpath("__init__.pyi").write_text("def f(x: int) -> str: ...")
+
+        loader = GriffeLoader(search_paths=[tmp_package.tmpdir])
+        package = loader.load_module(tmp_package.name)
+        assert "f" in package.members
+
+
+def test_load_single_module_from_both_py_and_pyi_files():
+    """Check that the loader is able to merge a single-module package loaded from `*.py` and `*.pyi` files.
+
+    This is a special case of the previous test: where  the package is a single module
+    distribution that also drops a `.pyi` file in site-packages.
+    """
+    with temporary_pypackage("just_a_folder", ["mod.py", "mod.pyi"]) as tmp_folder:
+        tmp_folder.path.joinpath("__init__.py").unlink()
+        tmp_folder.path.joinpath("mod.py").write_text("globals()['f'] = lambda x: str(x)")
+        tmp_folder.path.joinpath("mod.pyi").write_text("def f(x: int) -> str: ...")
+
+        loader = GriffeLoader(search_paths=[tmp_folder.path])
+        package = loader.load_module("mod")
+        assert "f" in package.members
